@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*--
 
-# Copyright (c) 2020, 2022 Oracle and its affiliates.
+# Copyright (c) 2020, 2022 Oracle and/or its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from __future__ import print_function, absolute_import, division
@@ -909,7 +909,7 @@ class ADSDataset(PandasDataset):
         Examples
         --------
         >>> ds = DatasetFactory.open("data.csv")
-        >>> ds.to_hdf(path="my/path.h5", key=)
+        >>> ds.to_hdf(path="my/path.h5", key="df")
         """
         if storage_options is None:
             import ads.dataset.factory as factory
